#
# spec file for package maim
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# See also http://en.opensuse.org/openSUSE:Specfile_guidelines
Name:           maim
Version:        5.8.0
Release:        2.1
Summary:        Flexible screenshotting utility
License:        GPL-3.0-or-later
Group:          Productivity/Graphics/Other
URL:            https://github.com/naelstrof/maim
Source0:        %{url}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake >= 3.7
BuildRequires:  gcc-c++
BuildRequires:  gengetopt
BuildRequires:  glm-devel
BuildRequires:  pkgconfig
BuildRequires:  slop-devel >= 7
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(icu-uc)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(xcomposite)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(zlib)
%if 0%{?suse_version} > 1600
# We must use the C++17 standard if we're using ICU >= 75
Patch0:         use_cxx17_standard.patch
%endif

%description
maim (Make Image) is a utility that takes screenshots of the desktop
using EGL. It is meant to overcome shortcomings of the "scrot"
utility and performs better in several ways.

%prep
%autosetup

%build
%cmake
%cmake_build

%install
%cmake_install

%files
%license COPYING
%doc README.md
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Mon Jun 10 2024 João Pedro Blos Lopes <jpblopes@gmail.com>
- Fix build with ICU >= 75.
- Add patch:
  * use_cxx17_standard.patch
- Patch from Arch Linux.
* Tue Apr 23 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to 5.8.0
  * Fixed hexadecimal parsing in parseWindow()
  * No longer defaults to Debug build type
  * Improved manpage for better apropos results
  * Added commands for decoding QR codes
  * Various readme and manpage improvements.
* Sat Jul 10 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 5.7.4
  * Supports webp, and bmp
  * Huge speed improvements
* Tue Aug 25 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 5.6.3
  * Do not consider root window's children as window frames
  * Add explicit TTY redirect error
  * Add support for the slop nodrag option
* Fri Dec 20 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 5.5.3
  * Avoid printing image output to a TTY
  * Add flag to capture background for transparent windows
* Thu Nov  8 2018 Ondřej Súkup <mimi.vx@gmail.com>
- use correct cmake macros
* Wed Nov  7 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 5.5.2 [boo#1113605]
  * maim respects _NET_FRAME_EXTENTS now, as well as XShape
    clipping.
* Fri Jun 26 2015 nemysis@gmx.ch
- Update to 3.3.41, no changelog entry
- Change Source0 Web URL, to have right maim-3.3.41.tar.gz
- Add BuildRequires for cmake and gengetopt
- Add BuildRoot
- Use %%{name} instead of maim
- Switch to manual installation, because in Source isn't install command
- Add Documentation
- Add %%changelog
* Mon Oct 20 2014 rneuhauser@suse.cz
- maim-2.3.17
* Fri Oct 17 2014 rneuhauser@suse.cz
- maim-2.2.13
